Struct Archetype

pub struct Archetype { /* private fields */ }
Collection of all entities with same set of components. Archetypes are typically managed by the World instance.

This type is exposed for Query implementations.

Implementations

Source

impl Archetype

pub fn new<'a>( components: impl Iterator<Item = &'a ComponentInfo> + Clone, ) -> Self

Creates new archetype with the given set of components.

pub fn has_component(&self, ty: TypeId) -> bool

Returns true if archetype contains component with specified id.

pub fn contains_borrow(&self, ty: TypeId) -> bool

Returns true if archetype contains component with specified id.

pub fn contains_borrow_mut(&self, ty: TypeId) -> bool

Returns true if archetype contains component with specified id.

pub fn matches(&self, type_ids: impl Iterator<Item = TypeId>) -> bool

Returns true if archetype matches components set specified.

pub fn ids(&self) -> impl ExactSizeIterator<Item = TypeId> + Clone + '_

Returns iterator over component type ids.

pub fn infos( &self, ) -> impl ExactSizeIterator<Item = &ComponentInfo> + Clone + '_

Returns iterator over component type infos.

pub fn spawn_empty(&mut self, id: EntityId) -> u32

Spawns new entity in the archetype.

Returns index of the newly created entity in the archetype.

pub fn spawn_one<T>(&mut self, id: EntityId, value: T, epoch: EpochId) -> u32
where T: 'static,

Spawns new entity in the archetype.

Returns index of the newly created entity in the archetype.

pub fn spawn<B>(&mut self, id: EntityId, bundle: B, epoch: EpochId) -> u32
where B: DynamicBundle,

Spawns new entity in the archetype.

Returns index of the newly created entity in the archetype.

pub fn despawn( &mut self, id: EntityId, idx: u32, encoder: LocalActionEncoder<'_>, ) -> Option<EntityId>

Despawns specified entity in the archetype.

Returns id of the entity that took the place of despawned.

pub unsafe fn despawn_unchecked( &mut self, id: EntityId, idx: u32, encoder: LocalActionEncoder<'_>, ) -> Option<EntityId>

Despawns specified entity in the archetype.

Returns id of the entity that took the place of despawned.

Safety

idx must be in bounds of the archetype entities array.

pub unsafe fn set_bundle<B>( &mut self, id: EntityId, idx: u32, bundle: B, epoch: EpochId, encoder: LocalActionEncoder<'_>, )
where B: DynamicBundle,

Set components from bundle to the entity.

Safety

Bundle must not contain components that are absent in this archetype.

pub unsafe fn set<T>( &mut self, id: EntityId, idx: u32, value: T, epoch: EpochId, encoder: LocalActionEncoder<'_>, )
where T: 'static,

Set component to the entity

Safety

Archetype must contain that component type.

pub unsafe fn get<T>(&mut self, entity_idx: u32) -> &T
where T: 'static,

Get component of the entity

Safety

Archetype must contain that component type.

pub unsafe fn get_mut<T>(&mut self, entity_idx: u32, epoch: EpochId) -> &mut T
where T: 'static,

Borrows component mutably. Updates component epoch.

Safety

Archetype must contain that component type. epoch must be advanced before this call.

pub unsafe fn get_mut_nobump<T>(&mut self, entity_idx: u32) -> &mut T
where T: 'static,

Borrows component mutably. Does not update component epoch.

Safety

Archetype must contain that component type.

pub unsafe fn insert_bundle<B>( &mut self, id: EntityId, dst: &mut Archetype, src_idx: u32, bundle: B, epoch: EpochId, encoder: LocalActionEncoder<'_>, replace: bool, ) -> (u32, Option<EntityId>)
where B: DynamicBundle,

Add components from bundle to the entity, moving entity to new archetype.

Safety

src_idx must be in bounds of this archetype. This archetype must not contain at least one component type from the bundle. dst archetype must contain all component types from this archetype and the bundle.

pub unsafe fn remove<T>( &mut self, id: EntityId, dst: &mut Archetype, src_idx: u32, ) -> (u32, Option<EntityId>, T)
where T: 'static,

Removes one component from the entity moving it to new archetype.

Safety

src_idx must be in bounds of this archetype. This archetype must contain specified type. dst archetype must contain all component types from this archetype except specified type.

pub unsafe fn drop_bundle( &mut self, id: EntityId, dst: &mut Archetype, src_idx: u32, encoder: LocalActionEncoder<'_>, ) -> (u32, Option<EntityId>)

Moves entity from one archetype to another. Dropping components types that are not present in dst archetype. All components present in dst archetype must be present in src archetype.

Safety

src_idx must be in bounds of this archetype. dst archetype must contain all component types from this archetype except types from bundle.