Module protocol

Module protocol 

Modules

adapters
JSON adapters for companion tool output.
cleanup
Protocol cleanup command: check for held resources and suggest cleanup.
context
ProtocolContext: cross-tool shared state collector.
executor
Step executor for protocol commands with –execute mode.
exit_policy
Exit-code and stderr policy for protocol commands.
finish
Protocol finish command: check state and output commands to finish a bone.
merge
Protocol merge command: lead-facing command to check preconditions and output merge steps for a worker’s completed workspace.
render
Shell-safe command renderer and protocol guidance types.
resume
Protocol resume command: check for in-progress work from a previous session.
review
Protocol review command: check state and output commands to request review.
review_gate
Shared review decision engine for protocol commands.
shell
Shell-safe primitives for protocol guidance rendering.

Structs

ProtocolArgs
Shared flags for all protocol subcommands.

Enums

ProtocolCommand