pub struct AgentsConfig {
pub dev: Option<DevAgentConfig>,
pub worker: Option<WorkerAgentConfig>,
pub reviewer: Option<ReviewerAgentConfig>,
pub responder: Option<ResponderAgentConfig>,
}Fields
dev: Option<DevAgentConfig>worker: Option<WorkerAgentConfig>reviewer: Option<ReviewerAgentConfig>responder: Option<ResponderAgentConfig>Trait Implementations
Sourceimpl Clone for AgentsConfig
impl Clone for AgentsConfig
Sourcefn clone(&self) -> AgentsConfig
fn clone(&self) -> AgentsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentsConfig
impl Debug for AgentsConfig
Sourceimpl Default for AgentsConfig
impl Default for AgentsConfig
Sourcefn default() -> AgentsConfig
fn default() -> AgentsConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AgentsConfig
impl<'de> Deserialize<'de> for AgentsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentsConfig
impl JsonSchema for AgentsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentsConfig
impl RefUnwindSafe for AgentsConfig
impl Send for AgentsConfig
impl Sync for AgentsConfig
impl Unpin for AgentsConfig
impl UnsafeUnpin for AgentsConfig
impl UnwindSafe for AgentsConfig