pub struct MissionsConfig {
pub enabled: bool,
pub max_workers: u32,
pub max_children: u32,
pub checkpoint_interval_sec: u64,
}Fields
enabled: boolmax_workers: u32max_children: u32checkpoint_interval_sec: u64Trait Implementations
Sourceimpl Clone for MissionsConfig
impl Clone for MissionsConfig
Sourcefn clone(&self) -> MissionsConfig
fn clone(&self) -> MissionsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissionsConfig
impl Debug for MissionsConfig
Sourceimpl Default for MissionsConfig
impl Default for MissionsConfig
Sourceimpl<'de> Deserialize<'de> for MissionsConfig
impl<'de> Deserialize<'de> for MissionsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MissionsConfig
impl JsonSchema for MissionsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MissionsConfig
impl RefUnwindSafe for MissionsConfig
impl Send for MissionsConfig
impl Sync for MissionsConfig
impl Unpin for MissionsConfig
impl UnsafeUnpin for MissionsConfig
impl UnwindSafe for MissionsConfig