pub struct ModelsConfig {
pub fast: Vec<String>,
pub balanced: Vec<String>,
pub strong: Vec<String>,
}Expand description
Model tier configuration for cross-provider load balancing.
Each tier maps to a list of provider/model:thinking strings.
When an agent config specifies a tier name (e.g. “fast”), resolve_model()
randomly picks one model from that tier’s pool.
Fields
fast: Vec<String>balanced: Vec<String>strong: Vec<String>Trait Implementations
Sourceimpl Clone for ModelsConfig
impl Clone for ModelsConfig
Sourcefn clone(&self) -> ModelsConfig
fn clone(&self) -> ModelsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelsConfig
impl Debug for ModelsConfig
Sourceimpl Default for ModelsConfig
impl Default for ModelsConfig
Sourceimpl<'de> Deserialize<'de> for ModelsConfig
impl<'de> Deserialize<'de> for ModelsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelsConfig
impl JsonSchema for ModelsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModelsConfig
impl RefUnwindSafe for ModelsConfig
impl Send for ModelsConfig
impl Sync for ModelsConfig
impl Unpin for ModelsConfig
impl UnsafeUnpin for ModelsConfig
impl UnwindSafe for ModelsConfig