pub struct MultiLeadConfig {
pub enabled: bool,
pub max_leads: u32,
pub merge_timeout_sec: u64,
}Fields
enabled: boolmax_leads: u32merge_timeout_sec: u64Trait Implementations
Sourceimpl Clone for MultiLeadConfig
impl Clone for MultiLeadConfig
Sourcefn clone(&self) -> MultiLeadConfig
fn clone(&self) -> MultiLeadConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiLeadConfig
impl Debug for MultiLeadConfig
Sourceimpl Default for MultiLeadConfig
impl Default for MultiLeadConfig
Sourceimpl<'de> Deserialize<'de> for MultiLeadConfig
impl<'de> Deserialize<'de> for MultiLeadConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MultiLeadConfig
impl JsonSchema for MultiLeadConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MultiLeadConfig
impl RefUnwindSafe for MultiLeadConfig
impl Send for MultiLeadConfig
impl Sync for MultiLeadConfig
impl Unpin for MultiLeadConfig
impl UnsafeUnpin for MultiLeadConfig
impl UnwindSafe for MultiLeadConfig