pub struct ReviewConfig {
pub enabled: bool,
pub reviewers: Vec<String>,
}Fields
enabled: boolreviewers: Vec<String>Trait Implementations
Sourceimpl Clone for ReviewConfig
impl Clone for ReviewConfig
Sourcefn clone(&self) -> ReviewConfig
fn clone(&self) -> ReviewConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewConfig
impl Debug for ReviewConfig
Sourceimpl Default for ReviewConfig
impl Default for ReviewConfig
Sourcefn default() -> ReviewConfig
fn default() -> ReviewConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReviewConfig
impl<'de> Deserialize<'de> for ReviewConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReviewConfig
impl JsonSchema for ReviewConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReviewConfig
impl RefUnwindSafe for ReviewConfig
impl Send for ReviewConfig
impl Sync for ReviewConfig
impl Unpin for ReviewConfig
impl UnsafeUnpin for ReviewConfig
impl UnwindSafe for ReviewConfig