Module subprocess

Module subprocess 

Structs

RunOutput
Result of running a subprocess.
Tool
Builder for running companion tools.

Functions

ensure_bus_hook
Ensure exactly one bus hook exists with the given description.
run_command
Simple helper to run a command with args, optionally in a specific directory. Returns stdout on success, or an error.