pub fn init() -> TelemetryGuardExpand description
Initialize telemetry based on OTEL_EXPORTER_OTLP_ENDPOINT.
Returns a guard that must be held until the program exits. Dropping the guard flushes any pending spans and logs.
pub fn init() -> TelemetryGuardInitialize telemetry based on OTEL_EXPORTER_OTLP_ENDPOINT.
Returns a guard that must be held until the program exits. Dropping the guard flushes any pending spans and logs.