pub enum ProtocolCommand {
Start {
bone_id: String,
dispatched: bool,
execute: bool,
args: ProtocolArgs,
},
Finish {
bone_id: String,
no_merge: bool,
force: bool,
execute: bool,
args: ProtocolArgs,
},
Review {
bone_id: String,
reviewers: Option<String>,
review_id: Option<String>,
execute: bool,
args: ProtocolArgs,
},
Cleanup {
execute: bool,
args: ProtocolArgs,
},
Resume {
args: ProtocolArgs,
},
Merge {
workspace: String,
message: Option<String>,
force: bool,
execute: bool,
args: ProtocolArgs,
},
}Variants
Start
Check state and output commands to start working on a bone
Fields

args: ProtocolArgsFinish
Check state and output commands to finish a bone
Fields

args: ProtocolArgsReview
Check state and output commands to request review
Fields

args: ProtocolArgsCleanup
Check for held resources and output cleanup commands
Resume
Check for in-progress work from a previous session
Fields

args: ProtocolArgsMerge
Check preconditions and output commands to merge a worker’s completed workspace
Fields

message: Option<String>Commit message for the merge (e.g. “feat: add login flow”). Use conventional commit prefix: feat:, fix:, chore:, etc. Required; opens $EDITOR on TTY if omitted.

args: ProtocolArgsImplementations