Module subprocess
edict
0.19.0
Module subprocess
Module Items
Structs
Functions
In crate edict
edict
Module
subprocess
Structs

RunOutput
Result of running a subprocess.
Tool
Builder for running companion tools.
Functions

ensure_
bus_
hook
Ensure exactly one bus hook exists with the given description.
run_
command
Simple helper to run a command with args, optionally in a specific directory. Returns stdout on success, or an error.